@@ -200,9 +200,8 @@ void Playlist::show (View *view)
 
         typedef std::map <String, PlaylistGroup *> GroupMap;
         GroupMap *groups = NULL;
-        String groupBy = view->getAttribute ("groupBy");
-        TrieString attr_groupBy (groupBy);
-        if (!groupBy.isEmpty ())
+        Expression *expr = evaluateExpr (view->getAttribute ("groupBy"));
+        if (expr)
             groups = new GroupMap;
 
         view->show->setRoot (this);
@@ -211,16 +210,20 @@ void Playlist::show (View *view)
             if (itm->data.node->isElementNode ()) {
                 Element *e = static_cast <Element *> (itm->data.node);
 
-                PlaylistItem *itm = new PlaylistItem (m_doc, app, false);
-                NodePtr guard = itm;
-                itm->setAttribute (StringPool::attr_url,
+                PlaylistItem *pli = new PlaylistItem (m_doc, app, false);
+                NodePtr guard = pli;
+                pli->setAttribute (StringPool::attr_url,
                         e->getAttribute (StringPool::attr_url));
-                itm->setAttribute (StringPool::attr_title,
+                pli->setAttribute (StringPool::attr_title,
                         e->getAttribute (StringPool::attr_title));
-                itm->setAuxiliaryNode (true);
-                itm->closed ();
+                pli->setAuxiliaryNode (true);
+                pli->closed ();
 
-                groupBy = e->getAttribute (attr_groupBy).stripWhiteSpace ();
+                String groupBy;
+                if (expr) {
+                    expr->setRoot (itm->data.node);
+                    groupBy = expr->toString ().stripWhiteSpace ();
+                }
                 if (groups && !groupBy.isEmpty ()) {
                     GroupMap::iterator it = groups->find (groupBy);
                     PlaylistGroup *group;
@@ -238,13 +241,14 @@ void Playlist::show (View *view)
                     } else {
                         group = it->second;
                     }
-                    group->appendChild (itm);
+                    group->appendChild (pli);
                 } else {
-                    insertBefore (itm, before);
+                    insertBefore (pli, before);
                 }
             }
         delete groups;
         delete lst;
+        delete expr;
         debugLog () << "Playlist;;show open " << open << endl;
         if (!open)
             SourceDocument::message (MsgListUpdated, NULL);
