@@ -158,8 +158,9 @@ public:
 class KMPLAYER_NO_EXPORT PlaylistGroup : public PlaylistGroupBase
 {
 public:
-    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, bool plmode=false);
-    KDE_NO_EXPORT const char * nodeName () const { return "group"; }
+    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, bool plmode=false)
+        : PlaylistGroupBase (doc, KMPlayer::id_node_group_node, a, plmode) {}
+    const char * nodeName () const;
 };
 
 class KMPLAYER_NO_EXPORT PlaylistMetaGroup : public PlaylistGroupBase
