@@ -268,20 +268,28 @@ bool UnixProcess::start (const String &pwd, const String &cmdline) {
     return false;
 }
 
+static void killProcessGroup (int sig)
+{
+    void (*oldhandler)(int) = signal (sig, SIG_IGN);
+    kill (-1 * getpid (), sig);
+    signal (sig, oldhandler);
+}
+
 void UnixProcess::stop () {
     closeStdIn ();
     closeStdOut ();
     if (process_id) {
-        ::kill (process_id, SIGINT);
-        for (int n = 0; process_id && n < 100; n++) {
+        errorLog () << "interupt process" << endl;
+        killProcessGroup (SIGINT);
+        for (int n = 0; process_id && n < 50; n++) {
             usleep (10000); // 10ms
             while (g_main_context_iteration (0L, false))
                 if (!process_id)
                     break;
         }
         if (process_id) {
-            errorLog () << "interupt process" << endl;
-            ::kill (process_id, SIGTERM);
+            errorLog () << "terminate process" << endl;
+            killProcessGroup (SIGTERM);
             for (int n = 0; process_id && n < 50; n++) {
                 usleep (10000); // 10ms
                 while (g_main_context_iteration (0L, false))
@@ -289,8 +297,10 @@ void UnixProcess::stop () {
                         break;
             }
         }
-        if (process_id)
+        if (process_id) {
+            ::kill (process_id, SIGKILL);
             processExited (process_id); // give up
+        }
     }
 }
 
@@ -544,10 +554,9 @@ KMPLAYER_NO_EXPORT bool MPlayer::quit () {
                 if (!unix_process.running ())
                     break;
         }
-        if (unix_process.running ()) {
-            errorLog () << "stop MPlayer" << endl;
+        if (unix_process.running ())
             unix_process.stop ();
-        }
+
         commands.clear ();
         request_quit = false;
     }
